# 爬取91tv的video
### 包括其目前为止的11w多部电影，以及每部电影的详细信息。

#### 可爬取的信息包括但不限于：
* 浏览量 <br>
* 收藏量<br>
* 演员<br>
* 分类(细分300余类)<br>
* 宣传图<br>
* 视频截图集锦<br>
* 中文标题<br>
* 中文内容描述<br>
* 上架时间<br>

----

#### 支持多进程批量下载video
注：下载原理为获取m3u8资源再通过ffmpeg转换为mp4 <br>
使用下载功能必须在电脑上安装ffmpeg并添加环境变量 <br>



